==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/contract_line_items_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractLineItemsController < AccountsManagementController
    # GET /documents/contract_line_items
    # GET /documents/contract_line_items.json
    def index
      @documents_contract_line_items = Documents::ContractLineItem.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_contract_line_items }
      end
    end

    # GET /documents/contract_line_items/1
    # GET /documents/contract_line_items/1.json
    def show
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_contract_line_item }
      end
    end

    # GET /documents/contract_line_items/new
    # GET /documents/contract_line_items/new.json
    def new
      @documents_contract_line_item = Documents::ContractLineItem.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_contract_line_item }
      end
    end

    # GET /documents/contract_line_items/1/edit
    def edit
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])
    end

    # POST /documents/contract_line_items
    # POST /documents/contract_line_items.json
    def create
      @documents_contract_line_item = Documents::ContractLineItem.new(params[:documents_contract_line_item])

      respond_to do |format|
        if @documents_contract_line_item.save
          format.html { redirect_to @documents_contract_line_item, :notice => 'Contract line item was successfully created.' }
          format.json { render :json => @documents_contract_line_item, :status => :created, :location => @documents_contract_line_item }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_contract_line_item.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contract_line_items/1
    # PUT /documents/contract_line_items/1.json
    def update
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])

      respond_to do |format|
        if @documents_contract_line_item.update_attributes(params[:documents_contract_line_item])
          format.html { redirect_to @documents_contract_line_item, :notice => 'Contract line item was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_contract_line_item.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contract_line_items/1
    # DELETE /documents/contract_line_items/1.json
    def destroy
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])
      @documents_contract_line_item.destroy

      respond_to do |format|
        format.html { redirect_to documents_contract_line_items_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/contract_line_items_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::ContractLineItemsController < AccountsManagementController
    # GET /documents/contract_line_items
    # GET /documents/contract_line_items.json
    def index
      @documents_contract_line_items = Documents::ContractLineItem.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_contract_line_items }
      end
    end

    # GET /documents/contract_line_items/1
    # GET /documents/contract_line_items/1.json
    def show
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_contract_line_item }
      end
    end

    # GET /documents/contract_line_items/new
    # GET /documents/contract_line_items/new.json
    def new
      @documents_contract_line_item = Documents::ContractLineItem.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_contract_line_item }
      end
    end

    # GET /documents/contract_line_items/1/edit
    def edit
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])
    end

    # POST /documents/contract_line_items
    # POST /documents/contract_line_items.json
    def create
      @documents_contract_line_item = Documents::ContractLineItem.new(params[:documents_contract_line_item])

      respond_to do |format|
        if @documents_contract_line_item.save
          format.html { redirect_to @documents_contract_line_item, notice: 'Contract line item was successfully created.' }
          format.json { render json: @documents_contract_line_item, status: :created, location: @documents_contract_line_item }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_contract_line_item.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/contract_line_items/1
    # PUT /documents/contract_line_items/1.json
    def update
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])

      respond_to do |format|
        if @documents_contract_line_item.update_attributes(params[:documents_contract_line_item])
          format.html { redirect_to @documents_contract_line_item, notice: 'Contract line item was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_contract_line_item.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/contract_line_items/1
    # DELETE /documents/contract_line_items/1.json
    def destroy
      @documents_contract_line_item = Documents::ContractLineItem.find(params[:id])
      @documents_contract_line_item.destroy

      respond_to do |format|
        format.html { redirect_to documents_contract_line_items_url }
        format.json { head :no_content }
      end
    end
  end
end
